Hedgeye Analysis
================

Provides code useful to Hedgeye data analysts and ensures essential Python packages we use are automatically available in every researcher's iPython Notebook. These include:

* Numpy
* Pandas
* Matplotlib
* IPython
* Seaborn
